@@ -1,5 +1,5 @@
 /*  Arg_parser - POSIX/GNU command line argument parser. (C version)
-    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
+    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*
-    Return values: 0 for a normal exit, 1 for environmental problems
+    Exit status: 0 for a normal exit, 1 for environmental problems
     (file not found, invalid flags, I/O errors, etc), 2 to indicate a
     corrupt or invalid input file, 3 for an internal consistency error
     (eg, bug) which caused arg_parser to panic.
@@ -31,7 +31,7 @@
 
 static const char * const Program_name = "Arg_parser";
 static const char * const program_name = "arg_parser";
-static const char * const program_year = "2013";
+static const char * const program_year = "2014";
 static const char * invocation_name = 0;
 
 
@@ -56,14 +56,14 @@ void show_help( const char verbose )
     {
     printf( "  -H, --hidden                 example of hidden option (shown with -v -h)\n" );
     }
-  printf( "\nReport bugs to bug-moe@gnu.org\n"
+  printf( "\nReport bugs to arg-parser-bug@nongnu.org\n"
           "Arg_parser home page: http://www.nongnu.org/arg-parser/arg_parser.html\n" );
   }
 
 
 void show_version()
   {
-  printf( "%s %s\n", Program_name, PROGVERSION );
+  printf( "%s %s\n", program_name, PROGVERSION );
   printf( "Copyright (C) %s Antonio Diaz Diaz.\n", program_year );
   printf( "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n"
           "This is free software: you are free to change and redistribute it.\n"
@@ -77,7 +77,7 @@ void show_error( const char * const msg, const int errcode, const char help )
     {
     fprintf( stderr, "%s: %s", program_name, msg );
     if( errcode > 0 )
-      fprintf( stderr, ": %s", strerror( errcode ) );
+      fprintf( stderr, ": %s.", strerror( errcode ) );
     fprintf( stderr, "\n" );
     }
   if( help )
@@ -88,7 +88,7 @@ void show_error( const char * const msg, const int errcode, const char help )
 
 void internal_error( const char * const msg )
   {
-  fprintf( stderr, "%s: internal error: %s.\n", program_name, msg );
+  fprintf( stderr, "%s: internal error: %s\n", program_name, msg );
   exit( 3 );
   }
 
@@ -112,16 +112,16 @@ int main( const int argc, const char * const argv[] )
   char verbose = 0;
   const struct ap_Option options[] =
     {
-    { 'H', "hidden",   ap_no    },
-    { 'V', "version",  ap_no    },
     { 'a', "append",   ap_no    },
     { 'b', "block",    ap_yes   },
     { 'c', "casual",   ap_maybe },
     { 'h', "help",     ap_no    },
+    { 'H', "hidden",   ap_no    },
     { 'o', 0,          ap_yes   },
     { 'q', "quiet",    ap_no    },
     { 'u', "uncaught", ap_no    },
     { 'v', "verbose",  ap_no    },
+    { 'V', "version",  ap_no    },
     { 256, "orphan",   ap_no    },
     {   0, 0,          ap_no    } };
 
@@ -130,7 +130,7 @@ int main( const int argc, const char * const argv[] )
   invocation_name = argv[0];
 
   if( !ap_init( &parser, argc, argv, options, 0 ) )
-    { show_error( "Memory exhausted.", 0, 0 ); return 1; }
+    { show_error( "Not enough memory.", 0, 0 ); return 1; }
   if( ap_error( &parser ) )				/* bad option */
     { show_error( ap_error( &parser ), 0, 1 ); return 1; }
 
@@ -140,18 +140,18 @@ int main( const int argc, const char * const argv[] )
     if( !code ) break;				/* no more options */
     switch( code )
       {
-      case 'H': break;				/* example, do nothing */
-      case 'V': show_version(); return 0;
       case 'a': break;				/* example, do nothing */
       case 'b': break;				/* example, do nothing */
       case 'c': break;				/* example, do nothing */
       case 'h': show_help( verbose ); return 0;
+      case 'H': break;				/* example, do nothing */
       case 'o': break;				/* example, do nothing */
       case 'q': verbose = 0; break;
       /* case 'u': break; */			/* intentionally not caught */
       case 'v': verbose = 1; break;
+      case 'V': show_version(); return 0;
       case 256: break;				/* example, do nothing */
-      default : internal_error( "uncaught option" );
+      default : internal_error( "uncaught option." );
       }
     } /* end process options */
 
