@@ -1,5 +1,5 @@
 /*  Arg_parser - POSIX/GNU command line argument parser. (C++ version)
-    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
+    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*
-    Return values: 0 for a normal exit, 1 for environmental problems
+    Exit status: 0 for a normal exit, 1 for environmental problems
     (file not found, invalid flags, I/O errors, etc), 2 to indicate a
     corrupt or invalid input file, 3 for an internal consistency error
     (eg, bug) which caused arg_parser to panic.
@@ -35,7 +35,7 @@ namespace {
 
 const char * const Program_name = "Arg_parser";
 const char * const program_name = "arg_parser";
-const char * const program_year = "2013";
+const char * const program_year = "2014";
 const char * invocation_name = 0;
 
 
@@ -60,14 +60,14 @@ void show_help( const bool verbose )
     {
     std::printf( "  -H, --hidden                 example of hidden option (shown with -v -h)\n" );
     }
-  std::printf( "\nReport bugs to bug-moe@gnu.org\n"
+  std::printf( "\nReport bugs to arg-parser-bug@nongnu.org\n"
                "Arg_parser home page: http://www.nongnu.org/arg-parser/arg_parser.html\n" );
   }
 
 
 void show_version()
   {
-  std::printf( "%s %s\n", Program_name, PROGVERSION );
+  std::printf( "%s %s\n", program_name, PROGVERSION );
   std::printf( "Copyright (C) %s Antonio Diaz Diaz.\n", program_year );
   std::printf( "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n"
                "This is free software: you are free to change and redistribute it.\n"
@@ -82,7 +82,7 @@ void show_error( const char * const msg, const int errcode = 0,
     {
     std::fprintf( stderr, "%s: %s", program_name, msg );
     if( errcode > 0 )
-      std::fprintf( stderr, ": %s", std::strerror( errcode ) );
+      std::fprintf( stderr, ": %s.", std::strerror( errcode ) );
     std::fprintf( stderr, "\n" );
     }
   if( help )
@@ -93,7 +93,7 @@ void show_error( const char * const msg, const int errcode = 0,
 
 void internal_error( const char * const msg )
   {
-  std::fprintf( stderr, "%s: internal error: %s.\n", program_name, msg );
+  std::fprintf( stderr, "%s: internal error: %s\n", program_name, msg );
   std::exit( 3 );
   }
 
@@ -120,16 +120,16 @@ int main( const int argc, const char * const argv[] )
 
   const Arg_parser::Option options[] =
     {
-    { 'H', "hidden",   Arg_parser::no    },
-    { 'V', "version",  Arg_parser::no    },
     { 'a', "append",   Arg_parser::no    },
     { 'b', "block",    Arg_parser::yes   },
     { 'c', "casual",   Arg_parser::maybe },
     { 'h', "help",     Arg_parser::no    },
+    { 'H', "hidden",   Arg_parser::no    },
     { 'o', 0,          Arg_parser::yes   },
     { 'q', "quiet",    Arg_parser::no    },
     { 'u', "uncaught", Arg_parser::no    },
     { 'v', "verbose",  Arg_parser::no    },
+    { 'V', "version",  Arg_parser::no    },
     { 256, "orphan",   Arg_parser::no    },
     {   0, 0,          Arg_parser::no    } };
 
@@ -143,28 +143,28 @@ int main( const int argc, const char * const argv[] )
     if( !code ) break;				// no more options
     switch( code )
       {
-      case 'H': break;				// example, do nothing
-      case 'V': show_version(); return 0;
       case 'a': break;				// example, do nothing
       case 'b': break;				// example, do nothing
       case 'c': break;				// example, do nothing
       case 'h': show_help( verbose ); return 0;
+      case 'H': break;				// example, do nothing
       case 'o': break;				// example, do nothing
       case 'q': verbose = false; break;
       // case 'u': break;			// intentionally not caught
       case 'v': verbose = true; break;
+      case 'V': show_version(); return 0;
       case 256: break;				// example, do nothing
-      default : internal_error( "uncaught option" );
+      default : internal_error( "uncaught option." );
       }
     } // end process options
 
   for( int argind = 0; argind < parser.arguments(); ++argind )
     {
     const int code = parser.code( argind );
-    const char * arg = parser.argument( argind ).c_str();
+    const char * const arg = parser.argument( argind ).c_str();
     if( code )	// option
       {
-      const char * name = optname( code, options );
+      const char * const name = optname( code, options );
       if( !name[1] )
         std::printf( "option '-%c'", name[0] );
       else
