@@ -1,6 +1,6 @@
 #! /bin/sh
 # check script for Arg_parser - POSIX/GNU command line argument parser.
-# Copyright (C) 2011, 2012, 2013 Antonio Diaz Diaz.
+# Copyright (C) 2011, 2012, 2013, 2014 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
 # to copy, distribute and modify it.
@@ -13,11 +13,11 @@ PARSER="${objdir}"/arg_parser
 CPARSER="${objdir}"/carg_parser
 framework_failure() { echo "failure in testing framework" ; exit 1 ; }
 
-if [ ! -x "${PARSER}" ] ; then
+if [ ! -f "${PARSER}" ] || [ ! -x "${PARSER}" ] ; then
 	echo "${PARSER}: cannot execute"
 	exit 1
 fi
-if [ ! -x "${CPARSER}" ] ; then
+if [ ! -f "${CPARSER}" ] || [ ! -x "${CPARSER}" ] ; then
 	echo "${CPARSER}: cannot execute"
 	exit 1
 fi
@@ -48,23 +48,23 @@ for i in "${PARSER}" "${CPARSER}" ; do
 	cmp ${in} out || fail=1
 	printf .
 
-	"$i" -aARG 2>/dev/null
-	if [ $? != 1 ] ; then fail=1 ; printf - ; else printf . ; fi
+	"$i" -aARG 2> /dev/null
+	if [ $? = 1 ] ; then printf . ; else printf - ; fail=1 ; fi
 
-	"$i" -b 2>/dev/null
-	if [ $? != 1 ] ; then fail=1 ; printf - ; else printf . ; fi
+	"$i" -b 2> /dev/null
+	if [ $? = 1 ] ; then printf . ; else printf - ; fail=1 ; fi
 
-	"$i" --block 2>/dev/null
-	if [ $? != 1 ] ; then fail=1 ; printf - ; else printf . ; fi
+	"$i" --block 2> /dev/null
+	if [ $? = 1 ] ; then printf . ; else printf - ; fail=1 ; fi
 
-	"$i" --block= 2>/dev/null
-	if [ $? != 1 ] ; then fail=1 ; printf - ; else printf . ; fi
+	"$i" --block= 2> /dev/null
+	if [ $? = 1 ] ; then printf . ; else printf - ; fail=1 ; fi
 
-	"$i" -x 2>/dev/null
-	if [ $? != 1 ] ; then fail=1 ; printf - ; else printf . ; fi
+	"$i" -x 2> /dev/null
+	if [ $? = 1 ] ; then printf . ; else printf - ; fail=1 ; fi
 
-	"$i" -u 2>/dev/null
-	if [ $? != 3 ] ; then fail=1 ; printf - ; else printf . ; fi
+	"$i" -u 2> /dev/null
+	if [ $? = 3 ] ; then printf . ; else printf - ; fail=1 ; fi
 done
 
 echo
